import {
  select, 
  csv, 
  scaleLinear,
  scaleTime, 
  extent, 
  axisLeft,
  axisBottom
} from 'd3';

const svg = select('svg');

const width = + svg.attr('width');
const height = +svg.attr('height'); //+ parses a string to a number

    // "mpg": "18",
    // "cylinders": "8",
    // "displacement": "307",
    // "horsepower": "130",
    // "weight": "3504",
    // "acceleration": "12",
    // "year": "1970",
    // "origin": "USA",
    // "name": "chevrolet chevelle malibu"


const render = data => {
  const title = 'A Week in San Francisco'
  
  const xValue = d => d.timestamp;
  const xAxisLabel = 'time';
  
  const yValue = d => d.temperature;
  const yAxisLabel = 'temperature';
  const circleRadius = 6;
  
  const margin = {top: 70, right: 40, bottom: 88, left: 105};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom
  
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
  .nice();  
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left}, ${margin.top})`
         );  
    
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);

  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  //yAxis(g.append('g'));
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('x', - innerHeight/2)
      .attr('y', -60)
      .attr('transform', 'rotate(-90)')
      .attr('fill', 'black')
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0, ${innerHeight})`);
    
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('x', innerWidth/2)
      .attr('y', 75)
      .attr('fill', 'black')
      .text(xAxisLabel);

  
  g.selectAll('circle').data(data) 
    .enter().append('circle')
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius);
  
  
  

  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};

csv('https://vizhub.com/curran/datasets/temperature-in-san-francisco.csv')
  .then(data => {
    data.forEach(d => {
      d.temperature = +d.temperature;
      d.timestamp = new Date(d.timestamp);
    });
 render(data); 
});